@@ -9,6 +9,7 @@ class Selector(ABC):
     @staticmethod
     def best_option(name: Optional[str] = None) -> "Selector":
         from .bemenu import Bemenu
+        from .choose import Choose
         from .dmenu import DMenu
         from .fuzzel import Fuzzel
         from .rofi import Rofi
@@ -16,7 +17,7 @@ class Selector(ABC):
         from .wmenu import WMenu
         from .wofi import Wofi
 
-        available_selectors = [Rofi, Wofi, Fuzzel, Bemenu, Tofi, DMenu, WMenu]
+        available_selectors = [Rofi, Wofi, Fuzzel, Bemenu, Tofi, DMenu, WMenu, Choose]
 
         if name is not None:
             try:
@@ -62,8 +63,11 @@ class Selector(ABC):
     def show_action_menu(self, additional_args: List[str]) -> List[Action]:
         pass
 
-    def basic_format_characters(self, characters: List[CharacterEntry]) -> List[str]:
-        return [f"{entry.character} {entry.description}" for entry in characters]
+    def basic_format_characters(self, characters: List[CharacterEntry], strip_tags: bool = True) -> List[str]:
+        return [
+            f"{entry.character} {entry.description.replace('<small>', '').replace('</small>', '') if strip_tags else entry.description}"
+            for entry in characters
+        ]
 
     def extract_char_from_basic_output(self, line: str) -> str:
         return re.match(r"^(?:\u200e(?! ))?(?P<char>.[^ ]*)( .*|$)", line).group("char")
