@@ -1,4 +1,5 @@
 from subprocess import run
+from typing import List
 
 from ..abstractionhelper import is_installed, is_wayland
 from .typer import Typer
@@ -35,3 +36,21 @@ class XDoToolTyper(Typer):
                 "0.05",
             ]
         )
+
+    def type_numerical(self, codepoints: List[int], active_window: str) -> None:
+        codepoint_list = " ".join([f"U{codepoint:x}" for codepoint in codepoints])
+
+        run(
+            [
+                "xdotool",
+                "windowfocus",
+                "--sync",
+                active_window,
+                "key",
+                "--clearmodifiers",
+                "Ctrl+Shift",
+                codepoint_list,
+                "sleep",
+                "0.05",
+            ]
+        )
